@@ -4,14 +4,14 @@ from click import BadParameter
 
 
 def python(program_file, input_data):
-    return subprocess.run(["python", program_file],
+    return subprocess.run(["python", str(program_file)],
                           input=input_data,
                           capture_output=True,
                           shell=True)
 
 
 def pypy(program_file, input_data):
-    return subprocess.run(["pypy", program_file],
+    return subprocess.run(["pypy", str(program_file)],
                           input=input_data,
                           capture_output=True,
                           shell=True)
@@ -24,15 +24,15 @@ def java(program_file, input_data):
             f"for java PROGRAM_FILE extention should be .java not {program_file.suffix}")
     classname = program_file.stem
     program_path = program_file.parent
-    subprocess.run(["javac", program_file])
-    return subprocess.run(["java", "-classpath", program_path, classname],
+    subprocess.run(["javac", str(program_file)])
+    return subprocess.run(["java", "-classpath", str(program_path), classname],
                           input=input_data,
                           capture_output=True,
                           shell=True)
 
 
 def exe(program_file, input_data):
-    return subprocess.run([program_file],
+    return subprocess.run([str(program_file)],
                           input=input_data,
                           capture_output=True,
                           shell=True)
